pub struct BearerHttpTransport { /* private fields */ }Expand description
HTTP transport that authenticates requests with a zeroizing bearer token.
Implementations
Sourceimpl BearerHttpTransport
impl BearerHttpTransport
Sourcepub fn from_secret(bearer_token: SecretString) -> Self
pub fn from_secret(bearer_token: SecretString) -> Self
Creates a bearer transport without exposing or copying its secret.
Sourcepub fn with_max_response_bytes(self, max_response_bytes: usize) -> Self
pub fn with_max_response_bytes(self, max_response_bytes: usize) -> Self
Sets the maximum accepted response body size in bytes.