pub struct StaticServiceLeadershipGuard { /* private fields */ }Expand description
In-memory service lease guard for embedded hosts and tests.
Implementations
Sourceimpl StaticServiceLeadershipGuard
impl StaticServiceLeadershipGuard
Sourcepub fn new(leases: impl IntoIterator<Item = ServiceLeaderLease>) -> Self
pub fn new(leases: impl IntoIterator<Item = ServiceLeaderLease>) -> Self
Creates a guard from zero or more independently scoped leases.
Sourcepub fn set_service_lease(
&self,
service_id: ServiceId,
lease: Option<ServiceLeaderLease>,
) -> ControlPlaneResult<()>
pub fn set_service_lease( &self, service_id: ServiceId, lease: Option<ServiceLeaderLease>, ) -> ControlPlaneResult<()>
Adds, renews, or removes the lease for one service.