pub struct FileControlPlane { /* private fields */ }Expand description
Durable control-plane implementation for one shared deployment directory.
Every operation takes an operating-system file lock, reloads validated state, applies one contract operation, and atomically persists the result. The deployment directory is the authentication and isolation boundary and is created with owner-only permissions on Unix.
Implementations
Sourceimpl FileControlPlane
impl FileControlPlane
Sourcepub fn open(
root: impl Into<PathBuf>,
retention_ms: u64,
) -> ControlPlaneResult<Self>
pub fn open( root: impl Into<PathBuf>, retention_ms: u64, ) -> ControlPlaneResult<Self>
Opens or creates a durable reference control plane.
Sourcepub fn with_clock(
root: impl Into<PathBuf>,
retention_ms: u64,
clock: Arc<dyn Clock>,
) -> ControlPlaneResult<Self>
pub fn with_clock( root: impl Into<PathBuf>, retention_ms: u64, clock: Arc<dyn Clock>, ) -> ControlPlaneResult<Self>
Opens a control plane using an explicit authoritative server clock.
Sourcepub fn state_path(&self) -> &Path
pub fn state_path(&self) -> &Path
Returns the durable state path.
Sourcepub fn retention_ms(&self) -> u64
pub fn retention_ms(&self) -> u64
Returns the presence retention window in milliseconds.
Sourcepub fn backup_to(&self, destination: impl AsRef<Path>) -> ControlPlaneResult<()>
pub fn backup_to(&self, destination: impl AsRef<Path>) -> ControlPlaneResult<()>
Creates an integrity-validated point-in-time state backup.
Sourcepub fn restore_from(&self, source: impl AsRef<Path>) -> ControlPlaneResult<()>
pub fn restore_from(&self, source: impl AsRef<Path>) -> ControlPlaneResult<()>
Replaces state from a validated backup.